@@ -1,6 +1,6 @@
 import pathlib, argparse, sys, os, logging
 
-from abritamr.AmrSetup import Setup, SetupAMR, SetupMDU
+from abritamr.AmrSetup import SetupAMR, SetupMDU
 from abritamr.RunFinder import RunFinder
 from abritamr.Collate import Collate, MduCollate
 from abritamr.version import __version__
@@ -13,6 +13,7 @@ abritamr is designed to implement AMRFinder and parse the results compatible for
 def run_pipeline(args):
     P = SetupAMR(args)
     input_data = P.setup()
+    print(input_data)
     A = RunFinder(input_data)
     amr_data = A.run()
     C = Collate(amr_data)
@@ -58,12 +59,14 @@ def set_parsers():
         default='', 
         help="Set the minimum identity of matches with amrfinder (0 - 1.0). Defaults to amrfinder preset, which is 0.9 unless a curated threshold is present for the gene."
     )
-    # parser_sub_run.add_argument(
-    #     "--amrfinder_db", 
-    #     "-d", 
-    #     default=f"{os.environ.get('AMRFINDER_DB')}", 
-    #     help="Path to amrfinder DB to use"
-    # )
+
+    parser_sub_run.add_argument(
+        "--amrfinder_db", 
+        "-d", 
+        default=f"{pathlib.Path(__file__).parent.parent /'abritamr' /'db' / 'amrfinderplus' / 'data' / '2021-09-30.1/'}", 
+        # default="/home/khhor/conda/envs/abritamr/share/amrfinderplus/data/2021-09-30.1/",
+        help="Path to amrfinder DB to use"
+    )
     parser_sub_run.add_argument(
         "--species",
         "-sp",
